@@ -81,17 +81,17 @@ class NetPriceCalculator(PriceCalculator):
 
         if object.get_for_sale():
             if object.is_variant() and not object.active_for_sale_price:
-                price = object.parent.get_for_sale_price(self.request)
+                price = object.parent.get_for_sale_price(self.request, with_properties)
             else:
-                price = object.get_for_sale_price(self.request)
+                price = object.get_for_sale_price(self.request, with_properties)
         else:
             if object.is_variant() and not object.active_price:
                 price = object.parent.price
             else:
                 price = object.price
 
-        if with_properties and object.is_configurable_product():
-            price += object.get_default_properties_price()
+            if with_properties and object.is_configurable_product():
+                price += object.get_default_properties_price()
 
         return price
 
